@@ -2,7 +2,14 @@
 from pkg_resources import DistributionNotFound, get_distribution
 
 from .exceptions import InvalidInputType
-from .pygeoutils import MatchCRS, arcgis2geojson, check_bbox, gtiff2xarray, json2geodf
+from .pygeoutils import (
+    MatchCRS,
+    arcgis2geojson,
+    check_bbox,
+    gtiff2xarray,
+    json2geodf,
+    xarray_geomask,
+)
 
 try:
     __version__ = get_distribution(__name__).version
